@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import (
@@ -114,18 +114,25 @@ class Exceptions:
     UnauthorizedException: Type[BotocoreClientError]
 
 
-class AppSyncClient:
+class AppSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        AppSyncClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#can_paginate)
         """
 
@@ -140,7 +147,9 @@ class AppSyncClient:
         atRestEncryptionEnabled: bool = None
     ) -> CreateApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_api_cache)
+        Creates a cache for the GraphQL API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_api_cache)
         """
 
@@ -148,7 +157,10 @@ class AppSyncClient:
         self, *, apiId: str, description: str = None, expires: int = None
     ) -> CreateApiKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_api_key)
+        Creates a unique key that you can distribute to clients who are executing your
+        API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_api_key)
         """
 
@@ -167,7 +179,9 @@ class AppSyncClient:
         relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None
     ) -> CreateDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_data_source)
+        Creates a `DataSource` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_data_source)
         """
 
@@ -184,7 +198,9 @@ class AppSyncClient:
         syncConfig: "SyncConfigTypeDef" = None
     ) -> CreateFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_function)
+        Creates a `Function` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_function)
         """
 
@@ -201,7 +217,9 @@ class AppSyncClient:
         xrayEnabled: bool = None
     ) -> CreateGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_graphql_api)
+        Creates a `GraphqlApi` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_graphql_api)
         """
 
@@ -220,7 +238,9 @@ class AppSyncClient:
         cachingConfig: "CachingConfigTypeDef" = None
     ) -> CreateResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_resolver)
+        Creates a `Resolver` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_resolver)
         """
 
@@ -228,55 +248,73 @@ class AppSyncClient:
         self, *, apiId: str, definition: str, format: TypeDefinitionFormatType
     ) -> CreateTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.create_type)
+        Creates a `Type` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.create_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#create_type)
         """
 
     def delete_api_cache(self, *, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_api_cache)
+        Deletes an `ApiCache` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_api_cache)
         """
 
     def delete_api_key(self, *, apiId: str, id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_api_key)
+        Deletes an API key.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_api_key)
         """
 
     def delete_data_source(self, *, apiId: str, name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_data_source)
+        Deletes a `DataSource` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_data_source)
         """
 
     def delete_function(self, *, apiId: str, functionId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_function)
+        Deletes a `Function` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_function)
         """
 
     def delete_graphql_api(self, *, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
+        Deletes a `GraphqlApi` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_graphql_api)
         """
 
     def delete_resolver(self, *, apiId: str, typeName: str, fieldName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_resolver)
+        Deletes a `Resolver` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_resolver)
         """
 
     def delete_type(self, *, apiId: str, typeName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.delete_type)
+        Deletes a `Type` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.delete_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#delete_type)
         """
 
     def flush_api_cache(self, *, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.flush_api_cache)
+        Flushes an `ApiCache` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.flush_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#flush_api_cache)
         """
 
@@ -288,31 +326,41 @@ class AppSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#generate_presigned_url)
         """
 
     def get_api_cache(self, *, apiId: str) -> GetApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_api_cache)
+        Retrieves an `ApiCache` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_api_cache)
         """
 
     def get_data_source(self, *, apiId: str, name: str) -> GetDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_data_source)
+        Retrieves a `DataSource` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_data_source)
         """
 
     def get_function(self, *, apiId: str, functionId: str) -> GetFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_function)
+        Get a `Function` .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_function)
         """
 
     def get_graphql_api(self, *, apiId: str) -> GetGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_graphql_api)
+        Retrieves a `GraphqlApi` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_graphql_api)
         """
 
@@ -320,7 +368,9 @@ class AppSyncClient:
         self, *, apiId: str, format: OutputTypeType, includeDirectives: bool = None
     ) -> GetIntrospectionSchemaResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
+        Retrieves the introspection schema for a GraphQL API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_introspection_schema)
         """
 
@@ -328,13 +378,17 @@ class AppSyncClient:
         self, *, apiId: str, typeName: str, fieldName: str
     ) -> GetResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_resolver)
+        Retrieves a `Resolver` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_resolver)
         """
 
     def get_schema_creation_status(self, *, apiId: str) -> GetSchemaCreationStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
+        Retrieves the current status of a schema creation operation.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_schema_creation_status)
         """
 
@@ -342,7 +396,9 @@ class AppSyncClient:
         self, *, apiId: str, typeName: str, format: TypeDefinitionFormatType
     ) -> GetTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.get_type)
+        Retrieves a `Type` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.get_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#get_type)
         """
 
@@ -350,7 +406,9 @@ class AppSyncClient:
         self, *, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListApiKeysResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_api_keys)
+        Lists the API keys for a given API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_api_keys)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_api_keys)
         """
 
@@ -358,7 +416,9 @@ class AppSyncClient:
         self, *, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListDataSourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_data_sources)
+        Lists the data sources for a given API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_data_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_data_sources)
         """
 
@@ -366,7 +426,9 @@ class AppSyncClient:
         self, *, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListFunctionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_functions)
+        List multiple functions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_functions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_functions)
         """
 
@@ -374,7 +436,9 @@ class AppSyncClient:
         self, *, nextToken: str = None, maxResults: int = None
     ) -> ListGraphqlApisResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
+        Lists your GraphQL APIs.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_graphql_apis)
         """
 
@@ -382,7 +446,9 @@ class AppSyncClient:
         self, *, apiId: str, typeName: str, nextToken: str = None, maxResults: int = None
     ) -> ListResolversResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_resolvers)
+        Lists the resolvers for a given API and type.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_resolvers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_resolvers)
         """
 
@@ -390,13 +456,17 @@ class AppSyncClient:
         self, *, apiId: str, functionId: str, nextToken: str = None, maxResults: int = None
     ) -> ListResolversByFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
+        List the resolvers that are associated with a specific function.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_resolvers_by_function)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
+        Lists the tags for a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_tags_for_resource)
         """
 
@@ -409,7 +479,9 @@ class AppSyncClient:
         maxResults: int = None
     ) -> ListTypesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.list_types)
+        Lists the types for a given API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.list_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#list_types)
         """
 
@@ -417,19 +489,25 @@ class AppSyncClient:
         self, *, apiId: str, definition: Union[bytes, IO[bytes], StreamingBody]
     ) -> StartSchemaCreationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.start_schema_creation)
+        Adds a new schema to your GraphQL API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.start_schema_creation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#start_schema_creation)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.tag_resource)
+        Tags a resource with user-supplied tags.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.untag_resource)
+        Untags a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#untag_resource)
         """
 
@@ -442,7 +520,9 @@ class AppSyncClient:
         type: ApiCacheTypeType
     ) -> UpdateApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_api_cache)
+        Updates the cache for the GraphQL API.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_api_cache)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_api_cache)
         """
 
@@ -450,7 +530,9 @@ class AppSyncClient:
         self, *, apiId: str, id: str, description: str = None, expires: int = None
     ) -> UpdateApiKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_api_key)
+        Updates an API key.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_api_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_api_key)
         """
 
@@ -469,7 +551,9 @@ class AppSyncClient:
         relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None
     ) -> UpdateDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_data_source)
+        Updates a `DataSource` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_data_source)
         """
 
@@ -487,7 +571,9 @@ class AppSyncClient:
         syncConfig: "SyncConfigTypeDef" = None
     ) -> UpdateFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_function)
+        Updates a `Function` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_function)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_function)
         """
 
@@ -504,7 +590,9 @@ class AppSyncClient:
         xrayEnabled: bool = None
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_graphql_api)
+        Updates a `GraphqlApi` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_graphql_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_graphql_api)
         """
 
@@ -523,7 +611,9 @@ class AppSyncClient:
         cachingConfig: "CachingConfigTypeDef" = None
     ) -> UpdateResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_resolver)
+        Updates a `Resolver` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_resolver)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_resolver)
         """
 
@@ -531,14 +621,17 @@ class AppSyncClient:
         self, *, apiId: str, typeName: str, format: TypeDefinitionFormatType, definition: str = None
     ) -> UpdateTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Client.update_type)
+        Updates a `Type` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Client.update_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/client.html#update_type)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_api_keys"]) -> ListApiKeysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listapikeyspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listapikeyspaginator)
         """
 
     @overload
@@ -546,13 +639,15 @@ class AppSyncClient:
         self, operation_name: Literal["list_data_sources"]
     ) -> ListDataSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListDataSources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listdatasourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listdatasourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_functions"]) -> ListFunctionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListFunctions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listfunctionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listfunctionspaginator)
         """
 
     @overload
@@ -560,13 +655,15 @@ class AppSyncClient:
         self, operation_name: Literal["list_graphql_apis"]
     ) -> ListGraphqlApisPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listgraphqlapispaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listgraphqlapispaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resolvers"]) -> ListResolversPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListResolvers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolverspaginator)
         """
 
     @overload
@@ -574,11 +671,13 @@ class AppSyncClient:
         self, operation_name: Literal["list_resolvers_by_function"]
     ) -> ListResolversByFunctionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolversbyfunctionpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listresolversbyfunctionpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_types"]) -> ListTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/appsync.html#AppSync.Paginator.ListTypes)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listtypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/appsync.html#AppSync.Paginator.ListTypes)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators.html#listtypespaginator)
         """
